# Desenvolvimento de Bibliotecas em Python 🧩
Bem-vindo ao repositório do projeto "Desenvolvimento de Bibliotecas". Aqui você encontrará uma biblioteca em Python desenvolvida com propósitos educacionais.

## Descrição do Projeto
Este projeto tem como objetivo principal a construção de um gerador aleatório de versículos da Bíblia.

## Funcionalidades Principais
 A biblioteca é capaz de disponibilizar versículos aleatórios da Bíblia, fornecendo uma abordagem educacional sobre seu conteúdo. Afinal, devemos trazer à memória aquilo que nos traz esperança! ❤️

## Instalação

```
pip install bible_verse
```

## Utilização

## Através de funções

**Obter verso em português**
```
from bible_verse.main import get_bible_verse_pt

verse = get_bible_verse_pt()
```

**Obter verso em inglês**
```
from bible_verse.main import get_bible_verse_en

verse = get_bible_verse_en()
```

## Através de comandos

**Obter verso em português**
```
bible_verse_pt
```

**Obter verso em inglês**
```
bible_verse_en
```



## Contato 📩
Para mais informações, entre em contato [comigo](ana_juh17@hotmail.com)! 😊
